==> indigitall_flutter_plugin-2.0.1.tar.gz: ios/Classes/IndigitallInAppFlutterPlugin.m <==
//
//  IndigitallInAppFlutterPlugin.m
//  indigitall_flutter_plugin
//
//  Created by indigitall on 18/1/23.
//

#import "IndigitallInAppFlutterPlugin.h"

@implementation IndigitallInAppFlutterPlugin

NSString *TOPICS_LIST = @"inAppTopicsList";
NSString *TOPICS_SUBSCRIBE = @"inAppTopicsSubscribe";
NSString *TOPICS_UNSUBSCRIBE = @"inAppTopicsUnsubscribe";

+ (void) getInAppModelWithParams:(NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *inAppCode;
        NSString *appKey;
        NSString *domainInApp;
        if (params[@"inAppCode"]) inAppCode = params[@"inAppCode"];
        if (params[@"appKey"]) appKey = params[@"appKey"];
        if (params[@"domainInApp"]) domainInApp = params[@"domainInApp"];
        [InAppUtils inAppWasGot:inAppCode didExpired:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didFound:^(INInApp * _Nonnull inApp) {
            [IndigitallInAppFParse jsonFromInApp:inApp withResult:result];
        } notFound:^{
            NSLog(@"InApp not found: calling method: Get InApp");
            [self inAppCreateData];
            [InAppHandler getInApp:inAppCode success:^(INInApp *inApp) {
                [InAppUtils addNewInApp:inApp];
                NSDateComponents *dateComponents = [NSDateComponents new];
                dateComponents.hour = inApp.cacheTtl;
                inApp.creationDate = [DateUtils getDateString:[DateUtils getDateNow]];
                inApp.expiredDate = [DateUtils getDateString:[DateUtils getDateExpired:dateComponents]];
                [IndigitallInAppFParse jsonFromInApp:inApp withResult:result];
            } errorLoad:^(INError *error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        } didDismissForever:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didShowManyTimes:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didClickOut:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        }];
    });
}

+ (void) inAppGetHtmlWithUrl: (NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        if (inApp.properties.InAppContentUrl != nil) {
            [[NSURLSession.sharedSession dataTaskWithURL:inApp.properties.InAppContentUrl completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
                if (data == nil){
                    NSLog(@"inAppGetHtml data: %@", error.localizedDescription);
                    return;
                }
                NSHTTPURLResponse *httpResponse = (NSHTTPURLResponse *) response;
                if (httpResponse.statusCode != 200){
                    NSLog(@"inAppGetHtml httpResponse.statusCode: %@", error.localizedDescription);
                    return;
                }
                NSString *content = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
                if (content == nil){
                    NSLog(@"inAppGetHtml content: %@", error.localizedDescription);
                    return;
                }
                
                NSString *contentHtml = content;
                if (inApp.customData != nil) {
                    for (int i = 0; i < inApp.customData.count; i++) {
                        contentHtml = [contentHtml stringByReplacingOccurrencesOfString:[NSString stringWithFormat:@"{{%@}}", [inApp.customData allKeys][i]] withString:[inApp.customData allValues][i]];
                    }
                }
                NSString *htmlWithoutOnClick = [contentHtml stringByReplacingOccurrencesOfString:@"InAppIndigitall.onClick" withString:@"IndigitallInApp.onClick"];
                NSString *htmlWiThJS = [NSString stringWithFormat:@"%@%@", htmlWithoutOnClick, InAppAPIConstants.INAPP_SCRIPT ];
                result(htmlWiThJS);
                
            }]resume];
        } else {
            NSLog(@"inAppGetHtml: No url on InApp object");
        }
    });
}

+ (void) showPopUpWithParams:(NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *inAppCode;
        BOOL closeIconDisabled = false;
        NSString *closeIconName;
        UIButton *button;
        if (params[@"inAppCode"]) inAppCode = params[@"inAppCode"];
        if ([params[@"closeIconDisabled"]boolValue] ==  true) closeIconDisabled = true;
        if (params[@"imageCloseButtonName"]){
            closeIconName = params[@"imageCloseButtonName"];
            button = [[UIButton alloc]init];
            [button setImage:[UIImage imageNamed:closeIconName] forState:normal];
            [button setTranslatesAutoresizingMaskIntoConstraints:false];
        }
        NSString *appKey;
        NSString *domainInApp = @"https://device-api.indigitall.com/v2";
        if (params[@"appKey"]) appKey = params[@"appKey"];
        if (params[@"domainInApp"]) domainInApp = params[@"domainInApp"];
        
        InAppConfig *config = [[InAppConfig alloc]init];
        config.appKey = appKey;
        config.domain = domainInApp;
        [INInAppDefaults setDomainInApp:domainInApp];
        [self inAppCreateData];
        [InAppIndigitall showPopupWithConfig:config popupId:inAppCode closeIcon:button closeIconDisabled:closeIconDisabled didAppear:^{
            result(@"");
        } didCancel:^{
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didCancel" withResult:result];
        } didTouchWithAction:^(INInAppAction * _Nonnull action) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didTouchWithAction" withResult:result];
        } didDismissed:^{
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didDismissed" withResult:result];
        } onShowTimeFinished:^(INInApp * _Nonnull inApp, int showTime) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:[NSString stringWithFormat:@"onShowTimeFinished after %d seconds", showTime] withResult:result];
        } didExpired:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didShowManyTimes:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didClickOut:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didDismissForever:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } failed:^(INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        }];
    });
}

+ (void) onClickWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        [InAppUtils inAppWasTappedWithInApp:inApp];
    });
}

+ (void) eventPrintInAppRequestWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        EventRequestInApp *request = [[EventRequestInApp alloc]initWithInApp:inApp];
        [InAppAPIClient postEventPrintRequest:request completion:[[BaseCallback alloc]init]];
    });
}

+ (void) topicsListWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        [InAppIndigitall topicsListWithOnSuccess:^(NSArray<INInAppTopic *> * _Nonnull topics) {
            [IndigitallInAppFParse jsonArrayFromtopics:topics withKey:TOPICS_LIST withResult:result];
        } onError:^(INError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromError:error withResult:result];
        }];
    });
}

+ (void) topicsSubscribeWithParams: (NSArray<NSString*>*)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        if (params != nil) {
            [InAppIndigitall topicsSubscribeWithArrayString:params onSuccess:^(NSArray<NSString *> * _Nonnull topics) {
                [IndigitallInAppFParse resultFromTopicString:topics withKey:TOPICS_SUBSCRIBE withResult:result];
            } onError:^(INError * _Nonnull error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        }
    });
}

+ (void) topicsUnsubscribeWithParams: (NSArray<NSString*>*)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        if (params != nil) {
            [InAppIndigitall topicsUnSubscribeWithArrayString:params onSuccess:^(NSArray<NSString *> * _Nonnull topics) {
                [IndigitallInAppFParse resultFromTopicString:topics withKey:TOPICS_UNSUBSCRIBE withResult:result];
            } onError:^(INError * _Nonnull error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        }
    });
}

+ (void) addNewInAppToDismissForeverWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        NSURL *url;
       if (inApp != nil) {
           [InAppUtils addNewInAppToDismissForever:inApp];
       }
    });
}

+ (void) inAppCreateData {
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *deviceId = [INInAppDefaults getDeviceId];
        if (deviceId == nil) {
            deviceId = [EventUtils generateUUID];
            [INInAppDefaults setDeviceId:deviceId];
        }
        if ([INInAppDefaults getExternalId] == nil) {
            NSString *code = [[[HmacUtils alloc]init] hmacsha256:deviceId  secret:[INInAppDefaults getAppKey]];
            [INInAppDefaults setExternalId:code];
        }
    });
}

@end

==> indigitall_flutter_plugin-2.0.2.tar.gz: ios/Classes/IndigitallInAppFlutterPlugin.m <==
//
//  IndigitallInAppFlutterPlugin.m
//  indigitall_flutter_plugin
//
//  Created by indigitall on 18/1/23.
//

#import "IndigitallInAppFlutterPlugin.h"

@implementation IndigitallInAppFlutterPlugin

NSString *INAPP_PLUGIN_TOPICS_LIST = @"inAppTopicsList";
NSString *INAPP_PLUGIN_TOPICS_SUBSCRIBE = @"inAppTopicsSubscribe";
NSString *INAPP_PLUGIN_TOPICS_UNSUBSCRIBE = @"inAppTopicsUnsubscribe";

+ (void) getInAppModelWithParams:(NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *inAppCode;
        NSString *appKey;
        NSString *domainInApp;
        if (params[@"inAppCode"]) inAppCode = params[@"inAppCode"];
        if (params[@"appKey"]) appKey = params[@"appKey"];
        if (params[@"domainInApp"]) domainInApp = params[@"domainInApp"];
        [InAppUtils inAppWasGot:inAppCode didExpired:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didFound:^(INInApp * _Nonnull inApp) {
            [IndigitallInAppFParse jsonFromInApp:inApp withResult:result];
        } notFound:^{
            NSLog(@"InApp not found: calling method: Get InApp");
            [self inAppCreateDataWithAppKey: appKey];
            [InAppHandler getInApp:inAppCode success:^(INInApp *inApp) {
                [InAppUtils addNewInApp:inApp];
                NSDateComponents *dateComponents = [NSDateComponents new];
                dateComponents.hour = inApp.cacheTtl;
                inApp.creationDate = [DateUtils getDateString:[DateUtils getDateNow]];
                inApp.expiredDate = [DateUtils getDateString:[DateUtils getDateExpired:dateComponents]];
                [IndigitallInAppFParse jsonFromInApp:inApp withResult:result];
            } errorLoad:^(INError *error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        } didDismissForever:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didShowManyTimes:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        } didClickOut:^(INInApp * _Nonnull inApp, INInAppError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromInAppError:error withResult:result];
        }];
    });
}

+ (void) inAppGetHtmlWithUrl: (NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        if (inApp.properties.InAppContentUrl != nil) {
            [[NSURLSession.sharedSession dataTaskWithURL:inApp.properties.InAppContentUrl completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
                if (data == nil){
                    NSLog(@"inAppGetHtml data: %@", error.localizedDescription);
                    return;
                }
                NSHTTPURLResponse *httpResponse = (NSHTTPURLResponse *) response;
                if (httpResponse.statusCode != 200){
                    NSLog(@"inAppGetHtml httpResponse.statusCode: %@", error.localizedDescription);
                    return;
                }
                NSString *content = [[NSString alloc] initWithData:data encoding:NSUTF8StringEncoding];
                if (content == nil){
                    NSLog(@"inAppGetHtml content: %@", error.localizedDescription);
                    return;
                }
                
                NSString *contentHtml = content;
                if (inApp.customData != nil) {
                    for (int i = 0; i < inApp.customData.count; i++) {
                        contentHtml = [contentHtml stringByReplacingOccurrencesOfString:[NSString stringWithFormat:@"{{%@}}", [inApp.customData allKeys][i]] withString:[inApp.customData allValues][i]];
                    }
                }
                NSString *htmlWithoutOnClick = [contentHtml stringByReplacingOccurrencesOfString:@"InAppIndigitall.onClick" withString:@"IndigitallInApp.onClick"];
                NSString *htmlWiThJS = [NSString stringWithFormat:@"%@%@", htmlWithoutOnClick, InAppAPIConstants.INAPP_SCRIPT ];
                result(htmlWiThJS);
                
            }]resume];
        } else {
            NSLog(@"inAppGetHtml: No url on InApp object");
        }
    });
}

+ (void) showPopUpWithParams:(NSDictionary *)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *inAppCode;
        BOOL closeIconDisabled = false;
        NSString *closeIconName;
        UIButton *button;
        if (params[@"popUpCode"]) inAppCode = params[@"popUpCode"];
        if ([params[@"closeIconDisabled"]boolValue] ==  true) closeIconDisabled = true;
        if (params[@"imageCloseButtonName"]){
            closeIconName = params[@"imageCloseButtonName"];
            button = [[UIButton alloc]init];
            [button setImage:[UIImage imageNamed:closeIconName] forState:normal];
            [button setTranslatesAutoresizingMaskIntoConstraints:false];
        }
        NSString *appKey;
        NSString *domainInApp = @"https://device-api.indigitall.com/v2";
        if (params[@"appKey"]) appKey = params[@"appKey"];
        if (appKey == nil) appKey = [INInAppDefaults getAppKey];
        if (params[@"domainInApp"]) domainInApp = params[@"domainInApp"];
        
        [self inAppCreateDataWithAppKey: appKey];
        InAppConfig *config = [[InAppConfig alloc]init];
        config.appKey = appKey;
        config.domainInApp = domainInApp;
        [INInAppDefaults setDomainInApp:domainInApp];
        [InAppIndigitall showPopupWithConfig:config popupId:inAppCode closeIcon:button closeIconDisabled:closeIconDisabled didAppear:^{
            result(@"");
        } didCancel:^{
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didCancel" withResult:result];
        } didTouchWithAction:^(INInAppAction * _Nonnull action) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didTouchWithAction" withResult:result];
        } didDismissed:^{
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:@"didDismissed" withResult:result];
        } onShowTimeFinished:^(INInApp * _Nonnull inApp, int showTime) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:[NSString stringWithFormat:@"onShowTimeFinished after %d seconds", showTime] withResult:result];
        } didExpired:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didShowManyTimes:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didClickOut:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } didDismissForever:^(INInApp * _Nonnull inApp, INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        } failed:^(INError * _Nonnull error) {
            [IndigitallInAppFParse setErrorWithErrorCode:@"INAPP_POPUP_ERROR" withMessage:error.message withResult:result];
        }];
    });
}

+ (void) onClickWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        [InAppUtils inAppWasTappedWithInApp:inApp];
    });
}

+ (void) eventPrintInAppRequestWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        EventRequestInApp *request = [[EventRequestInApp alloc]initWithInApp:inApp];
        [InAppAPIClient postEventPrintRequest:request completion:[[BaseCallback alloc]init]];
    });
}

+ (void) topicsListWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        [InAppIndigitall topicsListWithOnSuccess:^(NSArray<INInAppTopic *> * _Nonnull topics) {
            [IndigitallInAppFParse jsonArrayFromtopics:topics withKey:INAPP_PLUGIN_TOPICS_LIST withResult:result];
        } onError:^(INError * _Nonnull error) {
            [IndigitallInAppFParse jsonFromError:error withResult:result];
        }];
    });
}

+ (void) topicsSubscribeWithParams: (NSArray<NSString*>*)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        if (params != nil) {
            [InAppIndigitall topicsSubscribeWithArrayString:params onSuccess:^(NSArray<NSString *> * _Nonnull topics) {
                [IndigitallInAppFParse resultFromTopicString:topics withKey:INAPP_PLUGIN_TOPICS_SUBSCRIBE withResult:result];
            } onError:^(INError * _Nonnull error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        }
    });
}

+ (void) topicsUnsubscribeWithParams: (NSArray<NSString*>*)params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        if (params != nil) {
            [InAppIndigitall topicsUnSubscribeWithArrayString:params onSuccess:^(NSArray<NSString *> * _Nonnull topics) {
                [IndigitallInAppFParse resultFromTopicString:topics withKey:INAPP_PLUGIN_TOPICS_UNSUBSCRIBE withResult:result];
            } onError:^(INError * _Nonnull error) {
                [IndigitallInAppFParse jsonFromError:error withResult:result];
            }];
        }
    });
}

+ (void) addNewInAppToDismissForeverWithParams: (NSDictionary *) params result: (FlutterResult _Nonnull)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        INInApp *inApp = [[INInApp alloc]initWithJson:params];
        NSURL *url;
       if (inApp != nil) {
           [InAppUtils addNewInAppToDismissForever:inApp];
       }
    });
}

+ (void) inAppCreateDataWithAppKey: (NSString *)appKeyValue {
    NSString *appKey = appKeyValue;
    if (appKeyValue == nil) appKey = [INInAppDefaults getAppKey];
    dispatch_async(dispatch_get_main_queue(), ^{
        NSString *deviceId = [INInAppDefaults getDeviceId];
        if (deviceId == nil) {
            deviceId = [EventUtils generateUUID];
            [INInAppDefaults setDeviceId:deviceId];
        }
        if ([INInAppDefaults getExternalId] == nil && appKey != nil ) {
            NSString *code = [[[HmacUtils alloc]init] hmacsha256:deviceId  secret:appKey];
            [INInAppDefaults setExternalId:code];
        }
    });
}

@end
